@@ -1,19 +1,3 @@
-# Copyright (C) 2022-2025 Hibiki AI Limited <info@hibiki-ai.com>
-#
-# This file is part of nanonext.
-#
-# nanonext is free software: you can redistribute it and/or modify it under the
-# terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
-#
-# nanonext is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# nanonext. If not, see <https://www.gnu.org/licenses/>.
-
 # nanonext - Package -----------------------------------------------------------
 
 #' nanonext: NNG (Nanomsg Next Gen) Lightweight Messaging Library
@@ -86,20 +70,6 @@
 #' NNG: <https://nng.nanomsg.org/> \cr
 #' Mbed TLS: <https://www.trustedfirmware.org/projects/mbed-tls/>
 #'
-#' @encoding UTF-8
-#' @author Charlie Gao \email{charlie.gao@@shikokuchuo.net}
-#'   ([ORCID](https://orcid.org/0000-0002-0750-061X))
-#'
 #' @useDynLib nanonext, .registration = TRUE
 #'
 "_PACKAGE"
-
-
-#' Lock
-#'
-#' Stub function retained for compatibility purposes only.
-#'
-#' @keywords internal
-#' @export
-#'
-lock <- function() {} # may be removed after mirai > 2.1.0 is released
