@@ -1,19 +1,3 @@
-# Copyright (C) 2022-2025 Hibiki AI Limited <info@hibiki-ai.com>
-#
-# This file is part of nanonext.
-#
-# nanonext is free software: you can redistribute it and/or modify it under the
-# terms of the GNU General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any later
-# version.
-#
-# nanonext is distributed in the hope that it will be useful, but WITHOUT ANY
-# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# nanonext. If not, see <https://www.gnu.org/licenses/>.
-
 # nanonext - Options Configuration and Helper Functions ------------------------
 
 #' Get and Set Options for a Socket, Context, Stream, Listener or Dialer
@@ -283,8 +267,7 @@
 #'
 #' @export
 #'
-opt <- function(object, name)
-  .Call(rnng_get_opt, object, name)
+opt <- function(object, name) .Call(rnng_get_opt, object, name)
 
 #' @examples
 #' s <- socket("pair")
@@ -310,8 +293,7 @@ opt <- function(object, name)
 #' @rdname opt
 #' @export
 #'
-`opt<-` <- function(object, name, value)
-  .Call(rnng_set_opt, object, name, value)
+`opt<-` <- function(object, name, value) .Call(rnng_set_opt, object, name, value)
 
 #' Subscribe / Unsubscribe Topic
 #'
